==> tecfy_core_package-1.0.23.tar.gz: lib/views/components/home/notification_icon.dart <==
part of tecfy_core_client_package;

class NotificationIcon extends StatelessWidget {
  final Color color;
  NotificationIcon({required this.color});
  @override
  Widget build(BuildContext context) {
    return StreamBuilder<int>(
        stream: NotificationAppService.notificationCountStream,
        builder: (context, snap) => IconButton(
            tooltip: 'Notification',
            icon: Stack(
              children: <Widget>[
                Icon(Icons.notifications, color: color),
                CircleAvatar(
                    radius: 7,
                    backgroundColor:
                        NotificationAppService.notificationCount == 0
                            ? Colors.transparent
                            : Colors.red,
                    foregroundColor: Colors.white,
                    child: Text(
                      NotificationAppService.notificationCount == 0
                          ? ''
                          : NotificationAppService.notificationCount.toString(),
                      style: TextStyle(fontSize: 8),
                    ))
              ],
            ),
            onPressed: () {
              if (NotificationListService.isOpen) {
                NotificationListService.hide();
              } else {
                NotificationListService.show(parentContext: context);
              }
            }));
  }
}

class NotificationListService {
  static OverlayEntry? _activeOverlay;
  static Future<dynamic> Function()? beforeClose;

  static get isOpen => _activeOverlay != null;

  static Future hide() async {
    if (_activeOverlay == null) {
      return;
    }

    if (beforeClose != null) {
      await beforeClose?.call();
      _activeOverlay!.remove();
      _activeOverlay = null;
      await Future.delayed(Duration(milliseconds: 500));
      return;
    }
    try {
      _activeOverlay!.remove();
    } catch (err) {
      print('XXXXXXXXXXXX cannot remove old overlay $err');
    }
    _activeOverlay = null;
  }

  static Future show({required BuildContext parentContext, onClick}) async {
    await hide();
    _activeOverlay = OverlayEntry(
        builder: (BuildContext context) => NotificationsListPage(
            parentContext: parentContext, onCLick: onClick));

    if (TecfyCoreApp.appGlobalkey.currentState?.overlay != null) {
      TecfyCoreApp.appGlobalkey.currentState?.overlay?.insert(_activeOverlay!);
    } else {
      print(
          'NotificationList Error XXXXXXXXXXXXXXXXXXXXXXXXX context doesn\'t have overlat XXXXXXXXXXXXX');
      return;
    }
  }
}

==> tecfy_core_package-1.0.41.tar.gz: lib/views/components/home/notification_icon.dart <==
part of tecfy_core_client_package;

class NotificationIcon extends StatelessWidget {
  final Color color;
  NotificationIcon({required this.color});
  @override
  Widget build(BuildContext context) {
    return StreamBuilder<int>(
        stream: NotificationAppService.notificationCountStream,
        builder: (context, snap) => IconButton(
            tooltip: 'Notification',
            icon: Stack(
              children: <Widget>[
                Icon(Icons.notifications, color: color),
                CircleAvatar(
                    radius: 7,
                    backgroundColor:
                        NotificationAppService.notificationCount == 0
                            ? Colors.transparent
                            : Colors.red,
                    foregroundColor: Colors.white,
                    child: Text(
                      NotificationAppService.notificationCount == 0
                          ? ''
                          : NotificationAppService.notificationCount.toString(),
                      style: TextStyle(fontSize: 8),
                    ))
              ],
            ),
            onPressed: () {
              if (NotificationListService.isOpen) {
                NotificationListService.hide();
              } else {
                NotificationListService.show(parentContext: context);
              }
            }));
  }
}

class NotificationListService {
  static OverlayEntry? _activeOverlay;
  static Future<dynamic> Function()? beforeClose;

  static get isOpen => _activeOverlay != null;

  static Future hide() async {
    if (_activeOverlay == null) {
      return;
    }

    if (beforeClose != null) {
      await beforeClose?.call();
      _activeOverlay!.remove();
      _activeOverlay = null;
      await Future.delayed(Duration(milliseconds: 500));
      return;
    }
    try {
      _activeOverlay!.remove();
    } catch (err) {
      print('XXXXXXXXXXXX cannot remove old overlay $err');
    }
    _activeOverlay = null;
  }

  static Future show({required BuildContext parentContext, onClick}) async {
    await hide();
    _activeOverlay = OverlayEntry(
        builder: (BuildContext context) => NotificationsListPage(
            parentContext: parentContext, onCLick: onClick));

    if (TecfyBasicApp.appGlobalkey.currentState?.overlay != null) {
      TecfyBasicApp.appGlobalkey.currentState?.overlay?.insert(_activeOverlay!);
    } else {
      print(
          'NotificationList Error XXXXXXXXXXXXXXXXXXXXXXXXX context doesn\'t have overlat XXXXXXXXXXXXX');
      return;
    }
  }
}
